/****************************************************************************\
**  Title:       PCXWRITE.C                                                 **
**  Purpose:     Write PCX header information to a file.                    **
**  Version:     1.0                                                        **
**  Date:        May 1991                                                   **
**  Author:      James D. Murray, Anaheim, CA  USA                          **
**  C Compilers: Borland C++ v2.0, Microsoft C v6.00a                       **
**                                                                          **
**  Write the information contained within a PCXHEADER structure to a file. **
**                                                                          **
**  This module contains the following functions:                           **
**                                                                          **
**      WritePcxHeader - Write a PCX header to a file stream                **
**                                                                          **
**  Copyright (C) 1991 by Graphics Software Labs.  All rights reserved.     **
\****************************************************************************/
#include <stdio.h>
#include "endianio.h"
#include "pcx.h"

VOID (*PutWord)(WORD, FILE *);      /* Pointer to ENDIANIO function */

/*
**  Write the information from a PCX image file structure.
**
**  PCX header file information is read from the supplied PCX
**  header structure and written to the supplied FILE stream.
**  The ENDIANIO I/O finctions are used to insure that the header
**  information is written in little-endian order.
**
**  Returns: Nothing.
*/
VOID
WritePcxHeader(PcxHead, FpPcx)
PCXHEADER *PcxHead;     /* Pointer to PCX header structure  */
FILE      *FpPcx;       /* PCX image file output FILE stream */
{
    register SHORT i;

    PutWord = PutLittleWord;    /* Initialize ENDIANIO write function */

    PutByte(PcxHead->Id,             FpPcx);
    PutByte(PcxHead->Version,        FpPcx);
    PutByte(PcxHead->Format,         FpPcx);
    PutByte(PcxHead->BitsPixelPlane, FpPcx);
    PutWord(PcxHead->Xmin,           FpPcx);
    PutWord(PcxHead->Ymin,           FpPcx);
    PutWord(PcxHead->Xmax,           FpPcx);
    PutWord(PcxHead->Ymax,           FpPcx);
    PutWord(PcxHead->Hdpi,           FpPcx);
    PutWord(PcxHead->Vdpi,           FpPcx);

    /* Write the EGA Palette */
    for (i = 0; i < sizeof(PcxHead->EgaPalette); i++)
        PutByte(PcxHead->EgaPalette[i], FpPcx);

    PutByte(PcxHead->Reserved,       FpPcx);       
    PutByte(PcxHead->NumberOfPlanes, FpPcx);
    PutWord(PcxHead->BytesLinePlane, FpPcx); 
    PutWord(PcxHead->PaletteInfo,    FpPcx);  
    PutWord(PcxHead->HScreenSize,    FpPcx);  
    PutWord(PcxHead->VScreenSize,    FpPcx);

    /* Write the reserved area at the end of the header */
    for (i = 0; i < sizeof(PcxHead->Filler); i++)
        PutByte(PcxHead->Filler[i], FpPcx);
}

}
